@@ -17,7 +17,13 @@
 from __future__ import absolute_import
 
 try: # just a way to switch between CLI and PI
-    import calibre.constants
+    from calibre.constants import DEBUG
+    if os.environ.get('CALIBRE_WORKER', None) is not None or DEBUG:
+        loghandler.setLevel(logging.DEBUG)
+        logger.setLevel(logging.DEBUG)
+    else:
+        loghandler.setLevel(logging.CRITICAL)
+        logger.setLevel(logging.CRITICAL)
 except:
     import sys
     if sys.version_info >= (2, 7):
