@@ -27,8 +27,6 @@ from ..htmlcleanup import stripHTML
 from .. import exceptions as exceptions
 
 # py2 vs py3 transition
-from ..six import text_type as unicode
-from ..six.moves.urllib.error import HTTPError
 
 from .base_adapter import BaseSiteAdapter,  makeDate
 
@@ -62,12 +60,6 @@ class FicBookNetAdapter(BaseSiteAdapter):
         # http://docs.python.org/library/datetime.html#strftime-strptime-behavior
         self.dateformat = "%d %m %Y"
 
-    def use_pagecache(self):
-        '''
-        adapters that will work with the page cache need to implement
-        this and change it to True.
-        '''
-        return True
     @staticmethod # must be @staticmethod, don't remove it.
     def getSiteDomain():
         # The site domain.  Does have www here, if it uses it.
@@ -84,16 +76,8 @@ class FicBookNetAdapter(BaseSiteAdapter):
     def extractChapterUrlsAndMetadata(self):
         url=self.url
         logger.debug("URL: "+url)
-        try:
-            data = self._fetchUrl(url)
-        except HTTPError as e:
-            if e.code == 404:
-                raise exceptions.StoryDoesNotExist(self.url)
-            else:
-                raise e
+        data = self.get_request(url)
 
-
-        # use BeautifulSoup HTML parser to make everything easier to find.
         soup = self.make_soup(data)
 
         adult_div = soup.find('div',id='adultCoverWarning')
@@ -103,7 +87,6 @@ class FicBookNetAdapter(BaseSiteAdapter):
             else:
                 raise exceptions.AdultCheckRequired(self.url)
 
-        # Now go hunting for all the meta data and the chapter list.
 
         ## Title
         a = soup.find('section',{'class':'chapter-info'}).find('h1')
@@ -176,7 +159,7 @@ class FicBookNetAdapter(BaseSiteAdapter):
         ## after site change, I don't see word count anywhere.
         # pr=soup.find('a', href=re.compile(r'/printfic/\w+'))
         # pr='https://'+self.host+pr['href']
-        # pr = self.make_soup(self._fetchUrl(pr))
+        # pr = self.make_soup(self.get_request(pr))
         # pr=pr.findAll('div', {'class' : 'part_text'})
         # i=0
         # for part in pr:
@@ -241,7 +224,7 @@ class FicBookNetAdapter(BaseSiteAdapter):
 
         logger.debug('Getting chapter text from: %s' % url)
 
-        soup = self.make_soup(self._fetchUrl(url))
+        soup = self.make_soup(self.get_request(url))
 
         chapter = soup.find('div', {'id' : 'content'})
         if chapter == None: ## still needed?
