@@ -30,42 +30,17 @@ import re
 import time
 # py2 vs py3 transition
 from ..six import text_type as unicode
-from ..six.moves.urllib.error import HTTPError
 
 from .base_adapter import BaseSiteAdapter
 from .. import exceptions as exceptions
 from ..htmlcleanup import stripHTML
 from ..dateutils import parse_relative_date_string
 
-HTML_TAGS = (
-    'a', 'abbr', 'acronym', 'address', 'applet', 'area', 'article', 'aside', 'audio', 'b', 'base', 'basefont', 'bdi',
-    'bdo', 'big', 'blockquote', 'body', 'br', 'button', 'canvas', 'caption', 'center', 'cite', 'code', 'col',
-    'colgroup', 'datalist', 'dd', 'del', 'details', 'dfn', 'dialog', 'dir', 'div', 'dl', 'dt', 'em', 'embed',
-    'fieldset', 'figcaption', 'figure', 'font', 'footer', 'form', 'frame', 'frameset', 'h1', 'h2', 'h3', 'h4', 'h5',
-    'h6', 'head', 'header', 'hr', 'html', 'i', 'iframe', 'img', 'input', 'ins', 'kbd', 'label', 'legend', 'li', 'link',
-    'main', 'map', 'mark', 'menu', 'menuitem', 'meta', 'meter', 'nav', 'noframes', 'noscript', 'object', 'ol',
-    'optgroup', 'option', 'output', 'p', 'param', 'picture', 'pre', 'progress', 'q', 'rp', 'rt', 'ruby', 's', 'samp',
-    'script', 'section', 'select', 'small', 'source', 'span', 'strike', 'strong', 'style', 'sub', 'summary', 'sup',
-    'svg', 'table', 'tbody', 'td', 'template', 'textarea', 'tfoot', 'th', 'thead', 'time', 'title', 'tr', 'track', 'tt',
-    'u', 'ul', 'var', 'video', 'wbr')
-
-# TinyMCE-specific annotations, let's ignore these just like previously
-TINY_MCE_TAGS = 'anno', 'annotations'
-
 logger = logging.getLogger(__name__)
-pseudo_html_regex_format = r'(<+(?!/?(%s)>).*?>+)'
-real_html_regex = re.compile(r'</?(?:%s)(?:\s.*?)?\s*>' % '|'.join(HTML_TAGS), re.IGNORECASE)
 
 def getClass():
     return WWWWebNovelComAdapter
 
-
-def fix_pseudo_html(pseudo_html, whitelist_tags=()):
-    tags = set(HTML_TAGS).union(whitelist_tags)
-    pseudo_html_regex = re.compile(pseudo_html_regex_format % '|'.join(tags), re.IGNORECASE)
-    return pseudo_html_regex.sub(lambda match: escape(match.group(1)), pseudo_html)
-
-
 class WWWWebNovelComAdapter(BaseSiteAdapter):
     _GET_VIP_CONTENT_DELAY = 8
 
@@ -104,36 +79,21 @@ class WWWWebNovelComAdapter(BaseSiteAdapter):
         # https://www.webnovel.com/book/game-of-thrones%3A-the-prideful-one._17509790806343405
         return r'https://' + re.escape(self.getSiteDomain()) + r'/book/(?P<title>.*_)?(?P<id>\d+)'
 
-    def use_pagecache(self):
-        '''
-        adapters that will work with the page cache need to implement
-        this and change it to True.
-        '''
-        return True
-
     # Getting the chapter list and the meta data, plus 'is adult' checking.
     def doExtractChapterUrlsAndMetadata(self, get_cover=True):
         url = self.url
 
-        try:
-            data = self._fetchUrl(url)
-            # logger.debug(data)
-        except HTTPError as e:
-            if e.code == 404:
-                raise exceptions.StoryDoesNotExist('Error 404: {0}'.format(self.url))
-            else:
-                raise e
+        data = self.get_request(url)
+        # logger.debug("\n"+data)
 
         if 'We might have some troubles to find out this page.' in data:
             raise exceptions.StoryDoesNotExist('{0} says: "" for url "{1}"'.format(self.getSiteDomain(), self.url))
 
-        # use BeautifulSoup HTML parser to make everything easier to find.
         soup = self.make_soup(data)
         # removing all of the scripts
         for tag in soup.findAll('script') + soup.find_all('svg'):
             tag.extract()
 
-        # Now go hunting for all the meta data and the chapter list.
 
         # This is the block that holds the metadata
         bookdetails = soup.find('div', {'class': '_8'})
@@ -169,12 +129,14 @@ class WWWWebNovelComAdapter(BaseSiteAdapter):
         parse_meta(meta_txt,'Translator:','translator')
         parse_meta(meta_txt,'Editor:','editor')
 
-        cats = bookdetails.find_all('a',href=re.compile(r'/category/list'))
-        self.story.extendList('category',[stripHTML(cat) for cat in cats])
+        cattags = soup.find('div',{'class':'_mn'})
+        if cattags:
+            cats = cattags.find_all('a',href=re.compile(r'/category/'))
+            self.story.extendList('category',[stripHTML(cat) for cat in cats])
 
         poptags = soup.find('div',{'class':'m-tags'})
         if poptags:
-            sitetags = poptags.find_all('a',href=re.compile(r'/tag/list'))
+            sitetags = poptags.find_all('a',href=re.compile(r'/tags/'))
             self.story.extendList('sitetags',[sitetag.string.replace("# ","") for sitetag in sitetags])
 
         ## get _csrfToken cookie for chapter list fetch
@@ -186,11 +148,11 @@ class WWWWebNovelComAdapter(BaseSiteAdapter):
             raise exceptions.FailedToDownload('csrf token could not be found')
 
         ## get chapters from a json API url.
-        jsondata = json.loads(self._fetchUrl(
+        jsondata = json.loads(self.get_request(
             "https://" + self.getSiteDomain() + "/apiajax/chapter/GetChapterList?_csrfToken=" + csrf_token + "&bookId=" + self.story.getMetadata(
                 'storyId')))
-        # print json.dumps(jsondata, sort_keys=True,
-        #                  indent=2, separators=(',', ':'))
+        # logger.debug(json.dumps(jsondata, sort_keys=True,
+        #                         indent=2, separators=(',', ':')))
         for volume in jsondata["data"]["volumeItems"]:
             for chap in volume["chapterItems"]:
                 # Only allow free and VIP type 1 chapters
@@ -226,48 +188,15 @@ class WWWWebNovelComAdapter(BaseSiteAdapter):
     def getChapterText(self, url):
         logger.debug('Getting chapter text from: %s' % url)
 
-        book_id = self.story.getMetadata('storyId')
-        chapter_id = url.split('/')[-1]
-        content_url = 'https://%s/apiajax/chapter/GetContent?_csrfToken=%s&bookId=%s&chapterId=%s&_=%d' % (
-            self.getSiteDomain(), self._csrf_token, book_id, chapter_id, time.time() * 1000)
-        topdata = json.loads(self._fetchUrl(content_url))
-        # logger.debug(json.dumps(topdata, sort_keys=True,
-        #                         indent=2, separators=(',', ':')))
-        chapter_info = topdata['data']['chapterInfo']
+        soup = self.make_soup(self.get_request(url))
 
-        # Check if chapter is marked as VIP type 1 (requires an ad to be watched)
-        if chapter_info['isVip'] == 1:
-            content_token_url = 'https://%s/apiajax/chapter/GetChapterContentToken?_csrfToken=%s&bookId=%s&chapterId=%s' % (
-                self.getSiteDomain(), self._csrf_token, self.story.getMetadata('storyId'), chapter_id)
-            content_token = json.loads(self._fetchUrl(content_token_url))['data']['token']
+        for tag in soup.find_all('pirate'):
+            tag.decompose()
 
-            content_by_token_url = 'https://%s/apiajax/chapter/GetChapterContentByToken?_csrfToken=%s&token=%s' % (
-                self.getSiteDomain(), self._csrf_token, content_token)
+        save_chapter_soup = self.make_soup('<div class="story"></div>')
+        save_chapter=save_chapter_soup.find('div')
 
-            # This is actually required or the data/content field will be empty
-            time.sleep(self._GET_VIP_CONTENT_DELAY)
-            contents = json.loads(self._fetchUrl(content_by_token_url))['data']['contents']
-        else:
-            contents = chapter_info['contents']
+        for tag in soup.select("div.dib.pr p"):
+            save_chapter.append(tag)
 
-        # Content is HTML, so return it directly
-        if chapter_info['isRichFormat']:
-            content = "\n".join([ x['content'] for x in contents])
-            if self.getConfig('fix_pseudo_html', False):
-                # Attempt to fix pseudo HTML
-                fixed_content = fix_pseudo_html(content, TINY_MCE_TAGS)
-                if content != fixed_content:
-                    diff = difflib.unified_diff(
-                        real_html_regex.split(content),
-                        real_html_regex.split(fixed_content),
-                        n=0, lineterm='')
-                    logger.info('fix_pseudo_html() modified content:\n%s', '\n'.join(diff))
-                content = fixed_content
-        else: # text format.
-            content = "".join([ x['content'] for x in contents])
-            # Content is raw text, so convert paired newlines into paragraphs like the website
-            content = content.replace('\r', '')
-            content = escape(content)
-            content = re.sub(r'\n(.+?)\n', r'<p>\1</p>', content)
-        content = re.sub(r'(<|&lt;)pirate(>|&gt;).+?(<|&lt;)/pirate(>|&gt;)', r'', content)
-        return content
+        return self.utf8FromSoup(url,save_chapter)
