@@ -1,6 +1,7 @@
 import sys
 import os
 import time
+import traceback
 
 import gzip
 import zlib
@@ -170,11 +171,15 @@ class BaseBrowserCache(object):
 
     def get_key_mapping(self,url):
         # logger.debug("get_key_mapping:%s"%url)
-        ## on demamand map loading now.
+        ## on demand map loading now.
         ## browser_cache is shared between configurations
         ## XXX Needs some locking if multi-threading implemented.
         if not self.mapping_loaded:
-            self.do_map_cache_keys()
+            try:
+                self.do_map_cache_keys()
+            except Exception as e:
+                logger.debug(traceback.format_exc())
+                raise BrowserCacheException("Browser Cache Failed to Load with error '%s'"%e)
         return self.key_mapping.get(self.minimal_url(url),(None,None))[0]
 
     def get_data(self, url):
